@@ -87,7 +87,7 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
             value_array.append(dis.read_byte())
         elif dtype == "INT96":
             value_array.append(dis.read_utf())
-        elif dtype == "INTEGER":
+        elif dtype == "INTEGER" or dtype == "DATE":
             value_array.append(dis.read_int())
 
     if len(value_array) < 5:
