@@ -352,11 +352,11 @@ class Error(Exception):
 
 
 if __name__ == '__main__':
-    connection = connect(host="100.24.100.145",
-                         port=9002,
+    connection = connect(host="34.72.44.185",
+                         port=9000,
                          scheme="e6xdb",
                          username="admin",
-                         database="s3a://e6x-tpcds-spark/parquet330mb",
+                         database="gs://e6x-tpcds-benchmarks/parquet330mb",
                          auth=None,
                          configuration=None,
                          kerberos_service_name=None,
@@ -365,7 +365,7 @@ if __name__ == '__main__':
                          ssl_cert=None,
                          thrift_transport=None)
     cursor = Cursor(connection)
-    cursor.execute("SELECT i_item_id, Avg(ss_quantity)  agg1, Avg(ss_list_price) agg2, Avg(ss_coupon_amt) agg3, Avg(ss_sales_price) agg4 FROM  store_sales, customer_demographics, date_dim, item, promotion WHERE ss_sold_date_sk = d_date_sk AND ss_item_sk = i_item_sk AND ss_cdemo_sk = cd_demo_sk AND ss_promo_sk = p_promo_sk AND cd_gender = 'F' AND cd_marital_status = 'W' AND cd_education_status = '2 yr Degree' AND ( p_channel_email = 'N'    OR p_channel_event = 'N' ) AND d_year = 1998 GROUP BY i_item_id ORDER BY i_item_id")
+    cursor.execute("select * from date_dim")
     bdata = cursor._fetch_more()
     try:
         while bdata:
